==> apache-hive-4.0.1-src.tar.gz: apache-hive-4.0.1-src/ql/src/java/org/apache/hadoop/hive/ql/optimizer/calcite/HiveRelShuttle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.ql.optimizer.calcite;

import org.apache.calcite.rel.RelNode;
import org.apache.calcite.rel.RelShuttle;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveAggregate;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveFilter;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveJoin;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveProject;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveSortLimit;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveTableScan;

/**
 * Visitor that has methods for the common logical relational expressions.
 * This is required for HiveRelDecorrelation. Because we will have mix of
 *  HiveProject, LogicalProject etc we need an interface which can handle all
 */
public interface HiveRelShuttle extends RelShuttle {

    RelNode visit(HiveProject project);
    RelNode visit(HiveFilter filter);
    RelNode visit(HiveJoin join);
    RelNode visit(HiveAggregate aggregate);
    RelNode visit(HiveSortLimit hiveSortLimit);
    RelNode visit(HiveTableScan scan);
}

// End RelShuttle.java

==> apache-hive-4.2.0-src.tar.gz: apache-hive-4.2.0-src/ql/src/java/org/apache/hadoop/hive/ql/optimizer/calcite/HiveRelShuttle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.ql.optimizer.calcite;

import org.apache.calcite.rel.RelNode;
import org.apache.calcite.rel.RelShuttle;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveAggregate;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveFilter;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveJoin;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveProject;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveSortLimit;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.HiveTableScan;
import org.apache.hadoop.hive.ql.optimizer.calcite.reloperators.jdbc.HiveJdbcConverter;

/**
 * Visitor that has methods for the common logical relational expressions.
 * This is required for HiveRelDecorrelation. Because we will have mix of
 *  HiveProject, LogicalProject etc we need an interface which can handle all
 */
public interface HiveRelShuttle extends RelShuttle {

    RelNode visit(HiveProject project);
    RelNode visit(HiveFilter filter);
    RelNode visit(HiveJoin join);
    RelNode visit(HiveAggregate aggregate);
    RelNode visit(HiveSortLimit hiveSortLimit);
    RelNode visit(HiveTableScan scan);
    RelNode visit(HiveJdbcConverter conv);
}

// End RelShuttle.java
